make hip-tests compileable with TheRock (#1624)

## Motivation

Resolved: SWDEV-566226

The current implementation of agents inside of rocprof-systems keeps just the minimal necessary set of information required for populating the `info_agent` table inside of rocpd database. There is a sufficient amount of data that is being left out from database, so this change should fix that and store the additional agent information as an `extdata` row inside of `info_agent` table.

## Technical Details

This PR introduces additional filed inside of `agent` structure inside which is representing the JSON formatted string of all the additional information we can acquire about particular agent. This data is processed and added during the initial fetching of agents, and afterwards pushed inside of the database.

---------

Co-authored-by: David Galiffi <David.Galiffi@amd.com>

* SWDEV-557412 - Incorporate proper chunk offset when remapping virtual memory (#1848)

* SWDEV-557412 - Incorporate proper offset when remapping virtual memory

* Fix condition to check if VMHeap allocation address matches a chunk address

* Move offset calculation outside if/else block

---------

Co-authored-by: JeniferC99 <150404595+JeniferC99@users.noreply.github.com>

* SWDEV-567852 - Clean-up hip::init() (#1948)

* SWDEV-559267 - Use CLPrint to DevLogPrintf with Log Level - detail debug. (#1160)

* SWDEV-548892 - Stop using ocml isinf wrapper (#1854)

* SWDEV-562708 - change default maximum SVM size to 256GB (#1731)

* SWDEV-503089 - Fix and enable disabled HIP tests from math group (#1319)

* SWDEV-503089 - Fix and enable disabled HIP tests from math group

* SWDEV-503089 - Move single precision reduced run to a common function

* SWDEV-548892 - Stop using ockl steadyctr function (#1882)

Directly use the builtin

* Implement PTL support (#1957)

* Implement PTL support

Signed-off-by: adapryor <Adam.pryor@amd.com>
(cherry picked from commit 45bc31292e7940a3b8fca044ef7df22047b95733)

Signed-off-by: Maisam Arif <Maisam.Arif@amd.com>

---------

Signed-off-by: adapryor <Adam.pryor@amd.com>
Signed-off-by: Maisam Arif <Maisam.Arif@amd.com>
Co-authored-by: Maisam Arif <Maisam.Arif@amd.com>

* SWDEV-558080 - Add recommended granularity (#1176)

* Add recommended granularity

* Improve granularity testing

* Update based on feedback

* Fix and enable VMM tests on cuda (#1855)

* Fix and enable VMM tests on cuda

* Minor syntax fixes

---------

Co-authored-by: Rahul Manocha <rmanocha@amd.com>

* [rocprofiler-systems] Add support for ompt_callback_thread_begin (#1681)

* Add thread_begin callback

* Make OMPT callbacks that are instant have start_ts = end_ts

* SWDEV-567514: Remove default stream wait (#1977)

- when virtual map command is called

- can create deadlock

Signed-off-by: sdashmiz <shadi.dashmiz@amd.com>

* Fix flaky test Unit_hipStreamAddCallback_StrmSyncTiming (#2022)

* Review comments

* skip the 3 failing tests to merge hip-tests rocm-systems PR

---------

Signed-off-by: Bindhiya Kanangot Balakrishnan <Bindhiya.KanangotBalakrishnan@amd.com>
Signed-off-by: adapryor <Adam.pryor@amd.com>
Signed-off-by: Maisam Arif <Maisam.Arif@amd.com>
Signed-off-by: sdashmiz <shadi.dashmiz@amd.com>
Co-authored-by: GunaShekar <agunashe@amd.com>
Co-authored-by: agunashe <ajay.gunashekar@amd.com>
Co-authored-by: Ethan Trinh <Ethan.Trinh@amd.com>
Co-authored-by: JeniferC99 <150404595+JeniferC99@users.noreply.github.com>
Co-authored-by: Victor Zhang <111778801+victzhan@users.noreply.github.com>
Co-authored-by: German Andryeyev <56892148+gandryey@users.noreply.github.com>
Co-authored-by: usrihari123 <srihari.u@amd.com>
Co-authored-by: Bindhiya Kanangot Balakrishnan <Bindhiya.KanangotBalakrishnan@amd.com>
Co-authored-by: anujshuk-amd <anujshuk@amd.com>
Co-authored-by: itrowbri <Ian.Trowbridge@amd.com>
Co-authored-by: marantic-amd <marantic@amd.com>
Co-authored-by: David Galiffi <David.Galiffi@amd.com>
Co-authored-by: cadolphe-amd <chris.adolphe@amd.com>
Co-authored-by: Karthik Jayaprakash <54370791+kjayapra-amd@users.noreply.github.com>
Co-authored-by: Matt Arsenault <Matthew.Arsenault@amd.com>
Co-authored-by: Todd tiantuo Li <88386084+lttamd@users.noreply.github.com>
Co-authored-by: amilanov-amd <Aleksandar.Milanov@amd.com>
Co-authored-by: Adam Pryor <61172547+adam360x@users.noreply.github.com>
Co-authored-by: Maisam Arif <Maisam.Arif@amd.com>
Co-authored-by: AidanBeltonS <abeltons@amd.com>
Co-authored-by: Rahul Manocha <153310294+manocharahul@users.noreply.github.com>
Co-authored-by: Rahul Manocha <rmanocha@amd.com>
Co-authored-by: Kian Cossettini <Kian.Cossettini@amd.com>
Co-authored-by: Shadi Dashmiz <94885391+shadidashmiz@users.noreply.github.com>
Co-authored-by: Ioannis Assiouras <38722728+iassiour@users.noreply.github.com>
Co-authored-by: Ajay GunaShekar <86270081+agunashe@users.noreply.github.com>
This commit is contained in:
Jatin Chaudhary
2025-12-03 16:53:17 +00:00
committed by GitHub
parent f3ffd7070c
commit 8e1aee62d0
124 changed files with 1203 additions and 19124 deletions
@@ -97,37 +97,37 @@ void checkMemset(T value, size_t count, MemsetType memsetType, bool async = fals
switch (memsetType) {
case hipMemsetTypeDefault:
if (!async) {
INFO("Testing hipMemset call")
INFO("Testing hipMemset call");
HIP_MEMSET_CHECK(hipMemset, devPtr, value, count, false);
} else {
INFO("Testing hipMemsetAsync call")
INFO("Testing hipMemsetAsync call");
HIP_MEMSET_CHECK(hipMemsetAsync, devPtr, value, count, true);
}
break;
case hipMemsetTypeD8:
if (!async) {
INFO("Testing hipMemsetD8 call")
INFO("Testing hipMemsetD8 call");
HIP_MEMSET_CHECK_DTYPE(hipMemsetD8, devPtr, value, count, false);
} else {
INFO("Testing hipMemsetD8Async call")
INFO("Testing hipMemsetD8Async call");
HIP_MEMSET_CHECK_DTYPE(hipMemsetD8Async, devPtr, value, count, true);
}
break;
case hipMemsetTypeD16:
if (!async) {
INFO("Testing hipMemsetD16 call")
INFO("Testing hipMemsetD16 call");
HIP_MEMSET_CHECK_DTYPE(hipMemsetD16, devPtr, value, count, false);
} else {
INFO("Testing hipMemsetD16Async call")
INFO("Testing hipMemsetD16Async call");
HIP_MEMSET_CHECK_DTYPE(hipMemsetD16Async, devPtr, value, count, true);
}
break;
case hipMemsetTypeD32:
if (!async) {
INFO("Testing hipMemsetD32 call")
INFO("Testing hipMemsetD32 call");
HIP_MEMSET_CHECK_DTYPE(hipMemsetD32, devPtr, value, count, false);
} else {
INFO("Testing hipMemsetD32Async call")
INFO("Testing hipMemsetD32Async call");
HIP_MEMSET_CHECK_DTYPE(hipMemsetD32Async, devPtr, value, count, true);
}
break;
@@ -262,10 +262,10 @@ template <typename T> void checkMemset2D(T value, size_t width, size_t height, b
}
if (!async) {
INFO("Testing hipMemset2D call")
INFO("Testing hipMemset2D call");
HIP_CHECK(hipMemset2D(devPtr, pitch, value, width * elementSize, height));
} else {
INFO("Testing hipMemset2DAsync call")
INFO("Testing hipMemset2DAsync call");
HIP_CHECK(hipMemset2DAsync(devPtr, pitch, value, width * elementSize, height, stream));
HIP_CHECK(hipStreamSynchronize(stream));
}
@@ -355,7 +355,7 @@ template <typename T> void partialMemsetTest2D(T valA, T valB, size_t width, siz
checkMemset2D(valA, width, height, async, pitch, devPtr);
// Set partial region to be second value.
INFO("Setting partial square region")
INFO("Setting partial square region");
checkMemset2D(valB, subWidth, subHeight, async, pitch, devPtr);
auto hostPtr = get_device_data_2D<T>(devPtr, pitch, width, height);
@@ -424,7 +424,7 @@ void check_device_data_3D(hipPitchedPtr& devPitchedPtr, T value, hipExtent exten
for (size_t j = 0; j < height; j++) {
for (size_t i = 0; i < width; i++) {
idx = devPitchedPtr.pitch * height * k + devPitchedPtr.pitch * j + i;
INFO("idx=" << idx << " hostPtr[idx]=" << hostPtr[idx] << " value=" << value)
INFO("idx=" << idx << " hostPtr[idx]=" << hostPtr[idx] << " value=" << value);
HIP_ASSERT(hostPtr[idx] == value);
}
}
@@ -441,10 +441,10 @@ void checkMemset3D(hipPitchedPtr& devPitchedPtr, T value, hipExtent extent, bool
HIP_CHECK(hipMalloc3D(&devPitchedPtr, extent));
}
if (!async) {
INFO("Testing hipMemset3D call")
INFO("Testing hipMemset3D call");
HIP_CHECK(hipMemset3D(devPitchedPtr, value, extent));
} else {
INFO("Testing hipMemset3DAsync call")
INFO("Testing hipMemset3DAsync call");
HIP_CHECK(hipMemset3DAsync(devPitchedPtr, value, extent, stream));
HIP_CHECK(hipStreamSynchronize(stream));
}
@@ -531,9 +531,13 @@ void partialMemsetTest3D(T valA, T valB, size_t width, size_t height, size_t dep
hipExtent subExtent = make_hipExtent(subWidth * sizeof(T), subHeight, subDepth);
// Set entire region to be first value.
INFO("Setting full cuboid region") { checkMemset3D(devPitchedPtr, valA, extent, async); }
INFO("Setting full cuboid region");
checkMemset3D(devPitchedPtr, valA, extent, async);
// Set partial region to be second value.
INFO("Setting partial cuboid region") { checkMemset3D(devPitchedPtr, valB, subExtent, async); }
INFO("Setting partial cuboid region");
checkMemset3D(devPitchedPtr, valB, subExtent, async);
auto pitch = devPitchedPtr.pitch;
auto hostPtr = get_device_data_3D<T>(devPitchedPtr, extent);
T comparVal{0};